@@ -1,7 +1,8 @@
 import importlib
-from .Decorators import TimeFunc
 
-CountMainFuncs = importlib.import_module(name="CountMainFuncs", package="./CountMainFuncs.pyd")
+Decorators = importlib.import_module(name="Decorators", package=".Decorators.pyd")
+
+CountMainFuncs = importlib.import_module(name="CountMainFuncs", package=".CountMainFuncs.pyd")
 
 def CountToNumber(numToStopAt, Interval = 1, numToStartAt = 1, PrintOutput = True):
     CountMainFuncs.CountToNumber(numToStopAt=numToStopAt, Interval=Interval, numToStartAt=numToStartAt, PrintOutput=PrintOutput)
